==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/table/lang/az.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'az', {
	border: 'Sərhədlərin eni',
	caption: 'Cədvəlin başlığı',
	cell: {
		menu: 'Xana',
		insertBefore: 'Burdan əvvələ xanası çək',
		insertAfter: 'Burdan sonra xanası çək',
		deleteCell: 'Xanaları sil',
		merge: 'Xanaları birləşdir',
		mergeRight: 'Sağdan birləşdir',
		mergeDown: 'Soldan birləşdir',
		splitHorizontal: 'Üfüqi böl',
		splitVertical: 'Şaquli böl',
		title: 'Xanaların seçimləri',
		cellType: 'Xana növü',
		rowSpan: 'Sətirləri birləşdir',
		colSpan: 'Sütunları birləşdir',
		wordWrap: 'Sətirlərin sınması',
		hAlign: 'Üfüqi düzləndirmə',
		vAlign: 'Şaquli düzləndirmə',
		alignBaseline: 'Mətn xətti',
		bgColor: 'Doldurma rəngi',
		borderColor: 'Sərhədin rəngi',
		data: 'Məlumatlar',
		header: 'Başlıq',
		yes: 'Bəli',
		no: 'Xeyr',
		invalidWidth: 'Xanasın eni rəqəm olmalıdır.',
		invalidHeight: 'Xanasın hündürlüyü rəqəm olmalıdır.',
		invalidRowSpan: 'Birləşdirdiyiniz sütun xanaların sayı tam və müsbət rəqəm olmalıdır.',
		invalidColSpan: 'Birləşdirdiyiniz sətir xanaların sayı tam və müsbət rəqəm olmalıdır.',
		chooseColor: 'Seç'
	},
	cellPad: 'Xanalardakı kənar boşluqlar',
	cellSpace: 'Xanalararası interval',
	column: {
		menu: 'Sütun',
		insertBefore: 'Sola sütun əlavə et',
		insertAfter: 'Sağa sütun əlavə et',
		deleteColumn: 'Sütunları sil'
	},
	columns: 'Sütunlar',
	deleteTable: 'Cədvəli sil',
	headers: 'Başlıqlar',
	headersBoth: 'Hər ikisi',
	headersColumn: 'Birinci sütun',
	headersNone: 'yox',
	headersRow: 'Birinci sətir',
	invalidBorder: 'Sərhədlərin eni müsbət rəqəm olmalıdır.',
	invalidCellPadding: 'Xanalardakı kənar boşluqlar müsbət rəqəm olmalıdır.',
	invalidCellSpacing: 'Xanalararası interval müsbət rəqəm olmalıdır.',
	invalidCols: 'Sütunlarin sayı tam və müsbət olmalıdır.',
	invalidHeight: 'Cədvəlin hündürlüyü rəqəm olmalıdır.',
	invalidRows: 'Sətirlətin sayı tam və müsbət olmalıdır.',
	invalidWidth: 'Cədvəlin eni rəqəm olmalıdır.',
	menu: 'Cədvəl alətləri',
	row: {
		menu: 'Sətir',
		insertBefore: 'Yuxarıya sətir əlavə et',
		insertAfter: 'Aşağıya sətir əlavə et',
		deleteRow: 'Sətirləri sil'
	},
	rows: 'Sətirlər',
	summary: 'Xülasə',
	title: 'Cədvəl alətləri',
	toolbar: 'Cədvəl',
	widthPc: 'faiz',
	widthPx: 'piksel',
	widthUnit: 'en vahidi'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/az.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'az', {
	border: 'Sərhədlərin eni',
	caption: 'Cədvəlin başlığı',
	cell: {
		menu: 'Xana',
		insertBefore: 'Burdan əvvələ xanası çək',
		insertAfter: 'Burdan sonra xanası çək',
		deleteCell: 'Xanaları sil',
		merge: 'Xanaları birləşdir',
		mergeRight: 'Sağdan birləşdir',
		mergeDown: 'Soldan birləşdir',
		splitHorizontal: 'Üfüqi böl',
		splitVertical: 'Şaquli böl',
		title: 'Xanaların seçimləri',
		cellType: 'Xana növü',
		rowSpan: 'Sətirləri birləşdir',
		colSpan: 'Sütunları birləşdir',
		wordWrap: 'Sətirlərin sınması',
		hAlign: 'Üfüqi düzləndirmə',
		vAlign: 'Şaquli düzləndirmə',
		alignBaseline: 'Mətn xətti',
		bgColor: 'Doldurma rəngi',
		borderColor: 'Sərhədin rəngi',
		data: 'Məlumatlar',
		header: 'Başlıq',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Bəli',
		no: 'Xeyr',
		invalidWidth: 'Xanasın eni rəqəm olmalıdır.',
		invalidHeight: 'Xanasın hündürlüyü rəqəm olmalıdır.',
		invalidRowSpan: 'Birləşdirdiyiniz sütun xanaların sayı tam və müsbət rəqəm olmalıdır.',
		invalidColSpan: 'Birləşdirdiyiniz sətir xanaların sayı tam və müsbət rəqəm olmalıdır.',
		chooseColor: 'Seç'
	},
	cellPad: 'Xanalardakı kənar boşluqlar',
	cellSpace: 'Xanalararası interval',
	column: {
		menu: 'Sütun',
		insertBefore: 'Sola sütun əlavə et',
		insertAfter: 'Sağa sütun əlavə et',
		deleteColumn: 'Sütunları sil'
	},
	columns: 'Sütunlar',
	deleteTable: 'Cədvəli sil',
	headers: 'Başlıqlar',
	headersBoth: 'Hər ikisi',
	headersColumn: 'Birinci sütun',
	headersNone: 'yox',
	headersRow: 'Birinci sətir',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Sərhədlərin eni müsbət rəqəm olmalıdır.',
	invalidCellPadding: 'Xanalardakı kənar boşluqlar müsbət rəqəm olmalıdır.',
	invalidCellSpacing: 'Xanalararası interval müsbət rəqəm olmalıdır.',
	invalidCols: 'Sütunlarin sayı tam və müsbət olmalıdır.',
	invalidHeight: 'Cədvəlin hündürlüyü rəqəm olmalıdır.',
	invalidRows: 'Sətirlətin sayı tam və müsbət olmalıdır.',
	invalidWidth: 'Cədvəlin eni rəqəm olmalıdır.',
	menu: 'Cədvəl alətləri',
	row: {
		menu: 'Sətir',
		insertBefore: 'Yuxarıya sətir əlavə et',
		insertAfter: 'Aşağıya sətir əlavə et',
		deleteRow: 'Sətirləri sil'
	},
	rows: 'Sətirlər',
	summary: 'Xülasə',
	title: 'Cədvəl alətləri',
	toolbar: 'Cədvəl',
	widthPc: 'faiz',
	widthPx: 'piksel',
	widthUnit: 'en vahidi'
} );
